@@ -3,7 +3,7 @@ BEGIN {
   $Escape::Houdini::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Escape::Houdini::VERSION = '0.1.1';
+  $Escape::Houdini::VERSION = '0.1.2';
 }
 # ABSTRACT: Perl API to Houdini, a zero-dependency C web escaping library
 
@@ -18,7 +18,11 @@ our %EXPORT_TAGS = (
         escape_uri escape_url escape_href
         unescape_uri unescape_url 
         escape_js unescape_js
-        / ]
+        / ],
+    html => [ qw/ escape_html unescape_html /],
+    uri => [ qw/ escape_uri unescape_uri /],
+    url => [ qw/ escape_url unescape_url /],
+    js  => [ qw/ escape_js unescape_js /],
 );
 
 our @EXPORT_OK = @{$EXPORT_TAGS{all}};
@@ -37,7 +41,7 @@ Escape::Houdini - Perl API to Houdini, a zero-dependency C web escaping library
 
 =head1 VERSION
 
-version 0.1.1
+version 0.1.2
 
 =head1 SYNOPSIS
 
